import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { Hostable } from "../../Hostable";
import { Door } from "../../misc/Door";
import { AutoDoorsSystem, DoorsSystem, ElectricalDoorsSystem } from "../../systems";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerData } from "../../PlayerData";
import { DoorsEvent } from "./DoorsEvent";
/**
 * Emitted when a door is opened either by a player opening it manually, i.e.
 * the doors on Polus, or opened automatically after some time, i.e. the doors
 * on The Skeld.
 */
export declare class DoorsDoorOpenEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, DoorsEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly doorsystem: AutoDoorsSystem<RoomType> | DoorsSystem<RoomType> | ElectricalDoorsSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that opened the door. Only available if the client is the
     * host.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The door that the player opened.
     */
    readonly door: Door<RoomType>;
    static eventName: "doors.open";
    eventName: "doors.open";
    private _alteredDoor;
    constructor(room: RoomType, doorsystem: AutoDoorsSystem<RoomType> | DoorsSystem<RoomType> | ElectricalDoorsSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that opened the door. Only available if the client is the
     * host.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The door that the player opened.
     */
    door: Door<RoomType>);
    /**
     * The alternate door that will be opened, if changed.
     */
    get alteredDoor(): Door<RoomType>;
    /**
     * Change the door that was opened.
     * @param door The door to open.
     */
    setDoor(door: Door<RoomType> | number): void;
}
//# sourceMappingURL=Open.d.ts.map