"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HqHudConsoleCloseEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player closes a communications console on Mira HQ.
 */
class HqHudConsoleCloseEvent extends events_1.RevertableEvent {
    constructor(room, hqhudsystem, message, 
    /**
     * The player that closed the console.
     */
    player, 
    /**
     * The ID of the console that was closed.
     */
    consoleId) {
        super();
        this.room = room;
        this.hqhudsystem = hqhudsystem;
        this.message = message;
        this.player = player;
        this.consoleId = consoleId;
        this.eventName = "hqhud.consoles.close";
        this._alteredConsoleId = consoleId;
        this._alteredPlayer = player;
    }
    /**
     * The alternate ID of the console that will be closed, if changed.
     */
    get alteredConsoleId() {
        return this._alteredConsoleId;
    }
    /**
     * The alterenate player that will close the console, if changed.
     */
    get alteredPlayer() {
        return this._alteredPlayer;
    }
    /**
     * Change the ID of the console that was closed.
     * @param consoleId the ID of the conosle to close.
     */
    setConsoleId(consoleId) {
        this._alteredConsoleId = consoleId;
    }
    /**
     * Change the player that closed the console.
     * @param player The player to close the console.
     */
    setPlayer(player) {
        this._alteredPlayer = player;
    }
}
exports.HqHudConsoleCloseEvent = HqHudConsoleCloseEvent;
HqHudConsoleCloseEvent.eventName = "hqhud.consoles.close";
//# sourceMappingURL=ConsoleClose.js.map