import { RevertableEvent } from "@skeldjs/events";
import { CastVoteMessage } from "@skeldjs/protocol";
import { MeetingHud } from "../../objects";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { ProtocolEvent } from "../ProtocolEvent";
import { RoomEvent } from "../RoomEvent";
import { MeetingHudEvent } from "./MeetingHudEvent";
/**
 * Emitted when a player casts a vote on another player or skips vote in a
 * meeting.
 */
export declare class MeetingHudVoteCastEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, MeetingHudEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly meetinghud: MeetingHud<RoomType>;
    readonly message: CastVoteMessage | undefined;
    /**
     * The player that cast the vote.
     */
    readonly voter: PlayerData<RoomType>;
    /**
     * The player that the voter voted for.
     */
    readonly suspect: PlayerData<RoomType> | undefined;
    static eventName: "meeting.castvote";
    eventName: "meeting.castvote";
    private _alteredVoter;
    private _alteredSuspect;
    constructor(room: RoomType, meetinghud: MeetingHud<RoomType>, message: CastVoteMessage | undefined, 
    /**
     * The player that cast the vote.
     */
    voter: PlayerData<RoomType>, 
    /**
     * The player that the voter voted for.
     */
    suspect: PlayerData<RoomType> | undefined);
    /**
     * Whether the voter skipped the vote.
     */
    get didSkip(): boolean;
    /**
     * The altered player that will cast the vote instead, if changed.
     */
    get alteredVoter(): PlayerData<RoomType>;
    /**
     * The altered player that the voter voted for instead, if changed.
     */
    get alteredSuspect(): PlayerData<RoomType> | undefined;
    /**
     * Change the player that cast the vote.
     * @param voter The player to cast the vote.
     */
    setVoter(voter: PlayerData<RoomType>): void;
    /**
     * Change the player that the voter voted for.
     * @param suspect The player for the voter to vote for.
     */
    setSuspect(suspect: PlayerData<RoomType>): void;
}
//# sourceMappingURL=VoteCast.d.ts.map