"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSnapToEvent = void 0;
const events_1 = require("@skeldjs/events");
const util_1 = require("@skeldjs/util");
/**
 * Emitted when a player snaps to a position, without lerping. Typically emitted
 * when the player is moves between vents.
 */
class PlayerSnapToEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The old position of the player.
     */
    oldPosition, 
    /**
     * The new position of the player.
     */
    newPosition) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldPosition = oldPosition;
        this.newPosition = newPosition;
        this.eventName = "player.snapto";
        this._alteredPosition = new util_1.Vector2(newPosition);
    }
    /**
     * The altered position that the player will snap to instead, if changed.
     */
    get alteredPosition() {
        return this._alteredPosition;
    }
    /**
     * Revert the player's position back to their old position.
     */
    revert() {
        this.setPosition(this.oldPosition);
    }
    /**
     * Set the position that the player was snapped to.
     * @param position The position to snap to.
     */
    setPosition(position) {
        this._alteredPosition.x = position.x;
        this._alteredPosition.y = position.y;
    }
}
exports.PlayerSnapToEvent = PlayerSnapToEvent;
PlayerSnapToEvent.eventName = "player.snapto";
//# sourceMappingURL=SnapTo.js.map